@@ -65,6 +65,7 @@
 #include "keysets/humax.h"
 #include "keysets/hyundai.h"
 #include "keysets/ilo.h"
+#include "keysets/insignia.h"
 #include "keysets/irobot.h"
 #include "keysets/jvc.h"
 #include "keysets/kaon.h"
@@ -446,6 +447,13 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new ILOTV2(++counter));
   setupKeyset(new ILOTV3(++counter));
 
+  setupKeyset(new InsigniaTV1(++counter));
+  setupKeyset(new InsigniaTV2(++counter));
+  setupKeyset(new InsigniaTV3(++counter));
+  setupKeyset(new InsigniaDVD1(++counter));
+  setupKeyset(new InsigniaDVD2(++counter));
+  setupKeyset(new InsigniaDVD3(++counter));
+
   setupKeyset(new IRobotRoomba1(++counter));
 
   setupKeyset(new JVCSat1(++counter));
