@@ -1,6 +1,6 @@
 #include "mceprotocol.h"
 
-#include "pirrx51hardware.h"
+#include "pirinfraredled.h"
 
 #include "pirexception.h"
 
@@ -65,7 +65,7 @@ void MCEProtocol::startSendingCommand(
 //      throw PIRException(s);
     }
 
-    PIRRX51Hardware rx51device(carrierFrequency, dutyCycle);
+    PIRInfraredLED led(carrierFrequency, dutyCycle);
 
     int repeatCount = 0;
     int duration = 0;
@@ -81,25 +81,25 @@ void MCEProtocol::startSendingCommand(
       // c) three control bits, set to "110" (i.e., mode "6")
       // d) the double-sized "trailer" bit, set to 0.
 
-      rx51device.addSingle(HEADER_PULSE); // lead pulse
+      led.addSingle(HEADER_PULSE); // lead pulse
       duration += HEADER_PULSE;
-      rx51device.addSingle(HEADER_SPACE); // lead space
+      led.addSingle(HEADER_SPACE); // lead space
       duration += HEADER_SPACE;
-      rx51device.addSingle(biphaseUnit); // start bit pulse
+      led.addSingle(biphaseUnit); // start bit pulse
       duration += biphaseUnit;
-      rx51device.addSingle(biphaseUnit); // start bit space
+      led.addSingle(biphaseUnit); // start bit space
       duration += biphaseUnit;
-      rx51device.addSingle(biphaseUnit); // bit 1 pulse;
+      led.addSingle(biphaseUnit); // bit 1 pulse;
       duration += biphaseUnit;
-      rx51device.addSingle(biphaseUnit); // bit 1 space;
+      led.addSingle(biphaseUnit); // bit 1 space;
       duration += biphaseUnit;
-      rx51device.addSingle(biphaseUnit); // bit 2 pulse;
+      led.addSingle(biphaseUnit); // bit 2 pulse;
       duration += biphaseUnit;
-      rx51device.addSingle(2 * biphaseUnit); // bit 2 space + bit 3 space;
+      led.addSingle(2 * biphaseUnit); // bit 2 space + bit 3 space;
       duration += 2 * biphaseUnit;
-      rx51device.addSingle(biphaseUnit); // bit 3 pulse;
+      led.addSingle(biphaseUnit); // bit 3 pulse;
       duration += biphaseUnit;
-      rx51device.addSingle(2 * biphaseUnit); // trailer space
+      led.addSingle(2 * biphaseUnit); // trailer space
       duration += 2 * biphaseUnit;
       buffer = 2 * biphaseUnit; // trailer pulse goes into the buffer
       bufferContainsPulse = true;
@@ -107,34 +107,34 @@ void MCEProtocol::startSendingCommand(
       // Now, we can start the normal buffering process:
 
       // push the "OEM" data:
-      duration += pushBits(oemBits, rx51device);
+      duration += pushBits(oemBits, led);
 
       // The next bit is the MCE toggle bit:
       if (keypressCount % 2)
       {
-        pushOne(rx51device);
+        pushOne(led);
       }
       else
       {
-        pushZero(rx51device);
+        pushZero(led);
       }
 
       // push the device address data:
-      duration += pushBits(preData, rx51device);
+      duration += pushBits(preData, led);
 
       // push the command data:
-      duration += pushBits((*i).second.firstCode, rx51device);
+      duration += pushBits((*i).second.firstCode, led);
 
       // Flush out the buffer, if necessary:
       if (buffer)
       {
-        rx51device.addSingle(buffer);
+        led.addSingle(buffer);
         duration += buffer;
         buffer = 0;
       }
 
       // Actually send out the command:
-      rx51device.sendCommandToDevice();
+      led.sendCommandToDevice();
 
       // Sleep for an amount of time.  (RC6 demands an addtional 6 unit space
       // at the end of any command...)
@@ -167,7 +167,7 @@ void MCEProtocol::startSendingCommand(
 
 int MCEProtocol::pushBits(
   const CommandSequence &bits,
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   int duration = 0;
 
@@ -177,11 +177,11 @@ int MCEProtocol::pushBits(
   {
     if (*i)
     {
-      duration += pushOne(rx51device);
+      duration += pushOne(led);
     }
     else
     {
-      duration += pushZero(rx51device);
+      duration += pushZero(led);
     }
 
     ++i;
@@ -193,7 +193,7 @@ int MCEProtocol::pushBits(
 
 // This should be part of a general RC6 parent maybe?
 int MCEProtocol::pushZero(
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   // Need to add a space, then a pulse.
   int duration = 0;
@@ -201,7 +201,7 @@ int MCEProtocol::pushZero(
   if (bufferContainsSpace)
   {
     // Merge this space and the previous one, and send to device:
-    rx51device.addSingle(buffer + biphaseUnit);
+    led.addSingle(buffer + biphaseUnit);
     duration += (buffer + biphaseUnit);
     buffer = 0;
      bufferContainsSpace = false;
@@ -211,14 +211,14 @@ int MCEProtocol::pushZero(
     if (bufferContainsPulse)
     {
       // Flush out the buffer:
-      rx51device.addSingle(buffer);
+      led.addSingle(buffer);
       duration += buffer;
       buffer = 0;
       bufferContainsPulse = false;
     }
 
     // push a space onto the device:
-    rx51device.addSingle(biphaseUnit);
+    led.addSingle(biphaseUnit);
     duration += biphaseUnit;
   }
 
@@ -231,7 +231,7 @@ int MCEProtocol::pushZero(
 
 
 int MCEProtocol::pushOne(
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   // Need to add a pulse, then a space.
   int duration = 0;
@@ -239,7 +239,7 @@ int MCEProtocol::pushOne(
   // First, the pulse:
   if (bufferContainsPulse)
   {
-    rx51device.addSingle(buffer + biphaseUnit);
+    led.addSingle(buffer + biphaseUnit);
     duration += (buffer + biphaseUnit);
     buffer = 0;
     bufferContainsPulse = false;
@@ -249,13 +249,13 @@ int MCEProtocol::pushOne(
     if (bufferContainsSpace)
     {
       // Flush the buffer:
-      rx51device.addSingle(buffer);
+      led.addSingle(buffer);
       duration += buffer;
       buffer = 0;
       bufferContainsSpace = false;
     }
     // Now, add the pulse:
-    rx51device.addSingle(biphaseUnit);
+    led.addSingle(biphaseUnit);
     duration += biphaseUnit;
   }
 
