@@ -1,6 +1,6 @@
 #include "paceprotocol.h"
 
-#include "pirrx51hardware.h"
+#include "pirinfraredled.h"
 
 #include "pirexception.h"
 
@@ -60,16 +60,16 @@ void PaceProtocol::startSendingCommand(
     }
 
     // construct the device:
-    PIRRX51Hardware rx51device(carrierFrequency, dutyCycle);
+    PIRInfraredLED led(carrierFrequency, dutyCycle);
 
     int repeatCount = 0;
     int commandDuration = 0;
     while (repeatCount < MAX_REPEAT_COUNT)
     {
-      commandDuration = generateStandardCommand((*i).second, rx51device);
+      commandDuration = generateStandardCommand((*i).second, led);
 
       // Now, tell the device to send the whole command:
-      rx51device.sendCommandToDevice();
+      led.sendCommandToDevice();
 
       // sleep until the next repetition of command:
       sleepUntilRepeat(commandDuration);
@@ -111,34 +111,34 @@ void PaceProtocol::startSendingCommand(
 
 int PaceProtocol::generateStandardCommand(
   const PIRKeyBits &pkb,
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   int duration = 0;
 
   // First, the "header" pulse:
-  rx51device.addPair(headerPulse, headerSpace);
+  led.addPair(headerPulse, headerSpace);
   duration += (headerPulse + headerSpace);
 
   // Next, the toggle bit:
   if (keypressCount % 2)
   {
-    rx51device.addPair(onePulse, oneSpace);
+    led.addPair(onePulse, oneSpace);
     duration += (onePulse + oneSpace);
   }
   else
   {
-    rx51device.addPair(zeroPulse, zeroSpace);
+    led.addPair(zeroPulse, zeroSpace);
     duration += (zeroPulse + zeroSpace);
   }
 
   // Next, three bits of pre-data:
-  duration += pushBits(preData, rx51device);
+  duration += pushBits(preData, led);
 
   // Next, six bits of data:
-  duration += pushBits(pkb.firstCode, rx51device);
+  duration += pushBits(pkb.firstCode, led);
 
   // Finally add the "trail":
-  rx51device.addSingle(trailerPulse);
+  led.addSingle(trailerPulse);
   duration += trailerPulse;
 
   return duration;
