@@ -1,6 +1,6 @@
 #include "panasonicoldprotocol.h"
 
-#include "pirrx51hardware.h"
+#include "pirinfraredled.h"
 
 #include "pirexception.h"
 
@@ -58,16 +58,16 @@ void PanasonicOldProtocol::startSendingCommand(
     }
 
     // construct the device:
-    PIRRX51Hardware rx51device(carrierFrequency, dutyCycle);
+    PIRInfraredLED led(carrierFrequency, dutyCycle);
 
     int repeatCount = 0;
     int commandDuration = 0;
     while (repeatCount < MAX_REPEAT_COUNT)
     {
-      commandDuration = generateStandardCommand((*i).second, rx51device);
+      commandDuration = generateStandardCommand((*i).second, led);
 
       // Now, tell the device to send the whole command:
-      rx51device.sendCommandToDevice();
+      led.sendCommandToDevice();
 
       // sleep until the next repetition of command:
       sleepUntilRepeat(commandDuration);
@@ -103,12 +103,12 @@ void PanasonicOldProtocol::startSendingCommand(
 
 int PanasonicOldProtocol::generateStandardCommand(
   const PIRKeyBits &pkb,
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   int duration = 0;
 
   // First, the header pulse:
-  rx51device.addPair(headerPulse, headerSpace);
+  led.addPair(headerPulse, headerSpace);
   duration += (headerPulse + headerSpace);
 
   // This protocol uses 5 bits of address and 6 bits of command.  As with
@@ -122,13 +122,13 @@ int PanasonicOldProtocol::generateStandardCommand(
   // 3) repeat of the five bits of address data, inverted
   // 4) repeat of the six bits of command data, inverted
 
-  duration += pushReverseBits(pkb.firstCode, rx51device);
-  duration += pushReverseBits(pkb.secondCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.firstCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.secondCode, rx51device);
+  duration += pushReverseBits(pkb.firstCode, led);
+  duration += pushReverseBits(pkb.secondCode, led);
+  duration += pushInvertedReverseBits(pkb.firstCode, led);
+  duration += pushInvertedReverseBits(pkb.secondCode, led);
 
   // Add the trailer pulse:
-  rx51device.addSingle(trailerPulse);
+  led.addSingle(trailerPulse);
   duration += trailerPulse;
 
   return duration;
