@@ -1,6 +1,6 @@
 #include "pioneerprotocol.h"
 
-#include "pirrx51hardware.h"
+#include "pirinfraredled.h"
 
 #include "pirexception.h"
 #include <string>
@@ -63,7 +63,7 @@ void PioneerProtocol::startSendingCommand(
     }
 
     // construct the device:
-    PIRRX51Hardware rx51device(carrierFrequency, dutyCycle);
+    PIRInfraredLED led(carrierFrequency, dutyCycle);
 
     int repeatCount = 0;
     int commandDuration = 0;
@@ -74,15 +74,15 @@ void PioneerProtocol::startSendingCommand(
       // we always generate a standard command.
       if ((repeatCount % 2) && (!(i->second.thirdCode.empty())))
       {
-        commandDuration = generateSecondaryCommand(i->second, rx51device);
+        commandDuration = generateSecondaryCommand(i->second, led);
       }
       else
       {
-        commandDuration = generateStandardCommand(i->second, rx51device);
+        commandDuration = generateStandardCommand(i->second, led);
       }
 
       // Now, tell the device to send the whole command:
-      rx51device.sendCommandToDevice();
+      led.sendCommandToDevice();
 
       // sleep until the next repetition of command:
       sleepUntilRepeat(commandDuration);
@@ -119,25 +119,25 @@ void PioneerProtocol::startSendingCommand(
 
 int PioneerProtocol::generateStandardCommand(
   const PIRKeyBits &pkb,
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   int duration = 0;
 
   // First, the "header" pulse:
-  rx51device.addPair(headerPulse, headerSpace);
+  led.addPair(headerPulse, headerSpace);
   duration += (headerPulse + headerSpace);
 
   // Now, the data, following standard NEC rules.  (Note that we are not
   // using the "preData" value here, most Pioneer devices require more than
   // one address value.  Therefore, I'm requiring all keys to explicitly
   // load the address value into the "firstCode" member.)
-  duration += pushReverseBits(pkb.firstCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.firstCode, rx51device);
-  duration += pushReverseBits(pkb.secondCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.secondCode, rx51device);
+  duration += pushReverseBits(pkb.firstCode, led);
+  duration += pushInvertedReverseBits(pkb.firstCode, led);
+  duration += pushReverseBits(pkb.secondCode, led);
+  duration += pushInvertedReverseBits(pkb.secondCode, led);
 
   // Finally add the "trail":
-  rx51device.addSingle(trailerPulse);
+  led.addSingle(trailerPulse);
   duration += trailerPulse;
 
   return duration;
@@ -146,23 +146,23 @@ int PioneerProtocol::generateStandardCommand(
 
 int PioneerProtocol::generateSecondaryCommand(
   const PIRKeyBits &pkb,
-  PIRRX51Hardware &rx51device)
+  PIRInfraredLED &led)
 {
   int duration = 0;
 
   // First, the "header" pulse:
-  rx51device.addPair(headerPulse, headerSpace);
+  led.addPair(headerPulse, headerSpace);
   duration += (headerPulse + headerSpace);
 
   // Now, the data, following standard NEC rules.  (The secondary command
   // uses the third and fourth key codes.)
-  duration += pushReverseBits(pkb.thirdCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.thirdCode, rx51device);
-  duration += pushReverseBits(pkb.fourthCode, rx51device);
-  duration += pushInvertedReverseBits(pkb.fourthCode, rx51device);
+  duration += pushReverseBits(pkb.thirdCode, led);
+  duration += pushInvertedReverseBits(pkb.thirdCode, led);
+  duration += pushReverseBits(pkb.fourthCode, led);
+  duration += pushInvertedReverseBits(pkb.fourthCode, led);
 
   // Finally add the "trail":
-  rx51device.addSingle(trailerPulse);
+  led.addSingle(trailerPulse);
   duration += trailerPulse;
 
   return duration;
