@@ -34,6 +34,7 @@ PIRProtocol::PIRProtocol(
     id(index)
 {
   qRegisterMetaType<PIRKeyName>("PIRKeyName");
+  qRegisterMetaType<PIRACStateInfo>("PIRACStateInfo");
 
   QObject::connect(
     guiObject,
@@ -42,6 +43,13 @@ PIRProtocol::PIRProtocol(
     SLOT(startSendingCommand(unsigned int, PIRKeyName)),
     Qt::QueuedConnection);
 
+  QObject::connect(
+    guiObject,
+    SIGNAL(buttonPressed(PIRACStateInfo, unsigned int, PIRKeyName)),
+    this,
+    SLOT(startSendingStateInfo(PIRACStateInfo, unsigned int, PIRKeyName)),
+    Qt::QueuedConnection);
+
   QObject::connect(
     this,
     SIGNAL(commandFailed(const char *)),
@@ -399,6 +407,15 @@ void PIRProtocol::setPostData(
 }
 
 
+void PIRProtocol::startSendingStateInfo(
+  PIRACStateInfo state,
+  unsigned int threadableID,
+  PIRKeyName command)
+{
+  // This method can be ignored by most non-air-conditioner protocols.
+}
+
+
 bool PIRProtocol::isCommandSupported(
   PIRKeyName command)
 {
